@@ -1,6 +1,6 @@
 {% macro sqlserver__snapshot_hash_arguments(args) %}
     CONVERT(VARCHAR(32), HashBytes('MD5', {% for arg in args %}
-        coalesce(CONVERT(varchar, {{ arg }}, 121), '') {% if not loop.last %} + '|' + {% endif %}
+        coalesce(cast({{ arg }} as varchar(max)), '') {% if not loop.last %} + '|' + {% endif %}
     {% endfor %}), 2)
 {% endmacro %}
 
